@@ -206,7 +206,7 @@ class Terncy:
                             req["event"].set()
                     if "intent" in msgObj and msgObj["intent"] == "event":
                         if self._event_handler:
-                            ev = event.EventMessage(msg)
+                            ev = event.EventMessage(msgObj)
                             self._event_handler(self, ev)
                     if "intent" in msgObj and msgObj["intent"] == "ping":
                         await ws.send('{"intent":"pong"}')
@@ -254,7 +254,7 @@ class Terncy:
             return await self._wait_for_response(req_id, data, timeout)
 
     async def set_onoff(self, ent_uuid, state, wait_result=False, timeout=5):
-        return self.set_attribute(ent_uuid, "on", state, 0, wait_result)
+        return await self.set_attribute(ent_uuid, "on", state, 0, wait_result)
 
     async def set_attribute(
         self, ent_uuid, attr, attr_val, method, wait_result=False, timeout=5
